@@ -5,6 +5,7 @@ use base qw(Jifty::DBI::Record);
 use Jifty::DBI::Handle;
 
 use Cache::Simple::TimedExpiry;
+use Scalar::Util qw/ blessed /;
 
 use strict;
 use warnings;
@@ -84,6 +85,13 @@ sub _record_cache {
 
 }
 
+=head2 load_from_hash
+
+Overrides the implementation from L<Jifty::DBI::Record> to add caching.
+
+=cut
+
+
 sub load_from_hash {
     my $self = shift;
 
@@ -106,6 +114,12 @@ sub load_from_hash {
 
 }
 
+=head2 load_by_cols
+
+Overrides the implementation from L<Jifty::DBI::Record> to add caching.
+
+=cut
+
 sub load_by_cols {
     my ( $class, %attr ) = @_;
 
@@ -255,6 +269,9 @@ sub _gen_record_cache_key {
       push @cols, lc($key) . ( $value->{operator} || '=' )
           . defined $value->{value}? $value->{value}: '__undef';
     }
+    elsif ( blessed $value and $value->isa('Jifty::DBI::Record') ) {
+      push @cols, lc($key) . '=' . ( $value->id );
+    }
     else {
       push @cols, lc($key) . "=" . $value;
     }
