@@ -317,11 +317,11 @@ sub _init_column_for {
     croak "Illegal column definition for column $name in $from"
       if grep {not UNIVERSAL::isa($_, "Jifty::DBI::Schema::Trait")} @_;
 
-    $column->readable(!(delete $column->{unreadable}));
-    $column->writable(!(delete $column->{immutable}));
+    $column->readable(!(delete $column->attributes->{unreadable}));
+    $column->writable(!(delete $column->attributes->{immutable}));
 
     # XXX: deprecated
-    $column->mandatory(1) if delete $column->{not_null};
+    $column->mandatory(1) if delete $column->attributes->{not_null};
 
     $column->sort_order($SORT_ORDERS->{$from}++);
 
@@ -338,8 +338,11 @@ sub _init_column_for {
         }
 
         # Load the class we reference
-        $refclass->require();
-
+        unless (UNIVERSAL::isa($refclass, 'Jifty::DBI::Record') || UNIVERSAL::isa($refclass, 'Jifty::DBI::Collection')) {
+            local $UNIVERSAL::require::ERROR;
+            $refclass->require();
+            die $UNIVERSAL::require::ERROR if ($UNIVERSAL::require::ERROR);
+        }
         # References assume a refernce to an integer ID unless told otherwise
         $column->type('integer') unless ( $column->type );
 
@@ -371,9 +374,9 @@ sub _init_column_for {
             $column->by('id') unless $column->by;
             $column->virtual('1');
         } else {
-            warn "Error in $from: $refclass neither Record nor Collection";
+            warn "Error in $from: $refclass neither Record nor Collection. Perhaps it couldn't be loaded?";
         }
-    } elsif (my $handler = $column->{_init_handler}) {
+    } elsif (my $handler = $column->attributes->{_init_handler}) {
         $handler->($column, $from);
     } else {
         $column->type('varchar(255)') unless $column->type;
